@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  *
- * $Id: pcsc_demo.c 1375 2005-02-28 14:23:32Z rousseau $
+ * $Id: pcsc_demo.c,v 1.1.1.8 2006-08-11 18:49:11 rousseau Exp $
  */
 
 #include <stdio.h>
@@ -54,7 +54,7 @@ int main(int argc, char *argv[])
 	LONG rv;
 	SCARDCONTEXT hContext;
 	DWORD dwReaders;
-	LPTSTR mszReaders;
+	LPSTR mszReaders;
 	char *ptr, **readers = NULL;
 	int nbReaders;
 	SCARDHANDLE hCard;
