@@ -4,7 +4,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: wintypes.h,v 1.1.1.3 2005/09/06 20:29:07 rousseau Exp $
+ * $Id: wintypes.h,v 1.1.1.4 2006-08-11 18:49:10 rousseau Exp $
  */
 
 /**
@@ -42,15 +42,21 @@ extern "C"
 	typedef unsigned short WORD;
 	typedef long LONG;
 	typedef long RESPONSECODE;
-	typedef const char *LPCTSTR;
+	typedef const char *LPCSTR;
 	typedef const BYTE *LPCBYTE;
 	typedef BYTE *LPBYTE;
 	typedef DWORD *LPDWORD;
-	typedef char *LPTSTR;
+	typedef char *LPSTR;
 
 	/* this type is deprecated but still used by old drivers and applications
 	 * You should use LPTSTR instead */
-	typedef char *LPSTR
+	typedef char *LPTSTR
+#ifdef __GNUC__
+		/* __attribute__ is a GCC only extension */
+		__attribute__ ((deprecated))
+#endif
+		;
+	typedef const char *LPCTSTR
 #ifdef __GNUC__
 		/* __attribute__ is a GCC only extension */
 		__attribute__ ((deprecated))
