@@ -6,12 +6,12 @@
  * Copyright (C) 1999-2005
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debug.c,v 1.1.1.1 2006/04/22 18:58:39 rousseau Exp $
+ * $Id: debug.c,v 1.1.1.2 2006-08-11 18:49:09 rousseau Exp $
  */
 
 /**
  * @file
- * @brief This handles debugging.
+ * @brief This handles debugging for libpcsclite.
  */
  
 #include "config.h"
@@ -40,10 +40,7 @@ void log_init(void)
 	e = getenv("MUSCLECARD_DEBUG");
 #endif
 	if (e)
-	{
 		LogLevel = atoi(e);
-		printf("pouet %d\n", LogLevel);
-	}
 
 	/* no color under Windows */
 #ifndef WIN32
