@@ -6,12 +6,12 @@
  * Copyright (C) 1999-2005
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debuglog.c 1953 2006-03-21 13:46:28Z rousseau $
+ * $Id: debuglog.c 2050 2006-05-20 14:26:13Z rousseau $
  */
 
 /**
  * @file
- * @brief This handles debugging.
+ * @brief This handles debugging for pcscd.
  */
  
 #include "config.h"
@@ -128,9 +128,13 @@ void log_xxd(const int priority, const char *msg, const unsigned char *buffer,
 	for (i = 0; (i < len) && (c < debug_buf_end); ++i)
 	{
 		sprintf(c, "%02X ", buffer[i]);
-		c += strlen(c);
+		c += 3;
 	}
 
+	/* the buffer is too small so end it with "..." */
+	if ((c >= debug_buf_end) && (i < len))
+		c[-3] = c[-2] = c[-1] = '.';
+
 #ifndef WIN32
 	if (DEBUGLOG_SYSLOG_DEBUG == LogMsgType)
 		syslog(LOG_INFO, "%s", DebugBuffer);
