@@ -6,7 +6,7 @@
  * Copyright (C) 2004
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: eventhandler.c 1827 2006-01-24 14:49:52Z rousseau $
+ * $Id: eventhandler.c 2072 2006-06-06 09:31:07Z rousseau $
  */
 
 /**
@@ -76,7 +76,7 @@ LONG EHInitializeEventStructures(void)
 	{
 		readerStates[i] = (PREADER_STATE)
 			SYS_MemoryMap(sizeof(READER_STATE), fd, (i * pageSize));
-		if (readerStates[i] == 0)
+		if (readerStates[i] == MAP_FAILED)
 		{
 			Log3(PCSC_LOG_CRITICAL, "Cannot memory map public shared file %s: %s",
 				PCSCLITE_PUBSHM_FILE, strerror(errno));
@@ -203,7 +203,7 @@ LONG EHSpawnEventHandler(PREADER_CONTEXT rContext)
 void EHStatusHandlerThread(PREADER_CONTEXT rContext)
 {
 	LONG rv;
-	LPCTSTR lpcReader;
+	LPCSTR lpcReader;
 	DWORD dwStatus, dwReaderSharing;
 	DWORD dwCurrentState;
 	int pageSize;
