@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: ifdwrapper.c 1827 2006-01-24 14:49:52Z rousseau $
+ * $Id: ifdwrapper.c 2072 2006-06-06 09:31:07Z rousseau $
  */
 
 /**
@@ -120,7 +120,7 @@ LONG IFDOpenIFD(PREADER_CONTEXT rContext)
 #ifndef PCSCLITE_STATIC_DRIVER
 	RESPONSECODE(*IO_create_channel) (DWORD) = NULL;
 	RESPONSECODE(*IFDH_create_channel) (DWORD, DWORD) = NULL;
-	RESPONSECODE(*IFDH_create_channel_by_name) (DWORD, LPTSTR) = NULL;
+	RESPONSECODE(*IFDH_create_channel_by_name) (DWORD, LPSTR) = NULL;
 
 	if (rContext->dwVersion == IFD_HVERSION_1_0)
 		IO_create_channel =
