@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: readerfactory.c 2024 2006-04-22 18:52:09Z rousseau $
+ * $Id: readerfactory.c 2114 2006-07-31 13:28:50Z rousseau $
  */
 
 /**
@@ -57,7 +57,7 @@ LONG RFAllocateReaderSpace(void)
 	 */
 	for (i = 0; i < PCSCLITE_MAX_READERS_CONTEXTS; i++)
 	{
-		sReadersContexts[i] = (PREADER_CONTEXT) malloc(sizeof(READER_CONTEXT));
+		sReadersContexts[i] = malloc(sizeof(READER_CONTEXT));
 		(sReadersContexts[i])->vHandle = NULL;
 		(sReadersContexts[i])->readerState = NULL;
 	}
@@ -68,7 +68,7 @@ LONG RFAllocateReaderSpace(void)
 	return EHInitializeEventStructures();
 }
 
-LONG RFAddReader(LPTSTR lpcReader, DWORD dwPort, LPTSTR lpcLibrary, LPTSTR lpcDevice)
+LONG RFAddReader(LPSTR lpcReader, DWORD dwPort, LPSTR lpcLibrary, LPSTR lpcDevice)
 {
 	DWORD dwContext = 0, dwGetSize;
 	UCHAR ucGetData[1], ucThread[1];
@@ -211,8 +211,7 @@ LONG RFAddReader(LPTSTR lpcReader, DWORD dwPort, LPTSTR lpcLibrary, LPTSTR lpcDe
 
 	if ((sReadersContexts[dwContext])->pdwFeeds == NULL)
 	{
-		(sReadersContexts[dwContext])->pdwFeeds = 
-		  (DWORD *)malloc(sizeof(DWORD));
+		(sReadersContexts[dwContext])->pdwFeeds = malloc(sizeof(DWORD));
 
 		/* Initialize pdwFeeds to 1, otherwise multiple 
 		   cloned readers will cause pcscd to crash when 
@@ -225,14 +224,13 @@ LONG RFAddReader(LPTSTR lpcReader, DWORD dwPort, LPTSTR lpcLibrary, LPTSTR lpcDe
 	if ((sReadersContexts[dwContext])->mMutex == 0)
 	{
 		(sReadersContexts[dwContext])->mMutex =
-		  (PCSCLITE_MUTEX_T) malloc(sizeof(PCSCLITE_MUTEX));
+			malloc(sizeof(PCSCLITE_MUTEX));
 		SYS_MutexInit((sReadersContexts[dwContext])->mMutex);
 	}
 
 	if ((sReadersContexts[dwContext])->pdwMutex == NULL)
 	{
-		(sReadersContexts[dwContext])->pdwMutex = 
-		  (DWORD *)malloc(sizeof(DWORD));
+		(sReadersContexts[dwContext])->pdwMutex = malloc(sizeof(DWORD));
 
 		*(sReadersContexts[dwContext])->pdwMutex = 1;
 	}
@@ -404,11 +402,10 @@ LONG RFAddReader(LPTSTR lpcReader, DWORD dwPort, LPTSTR lpcLibrary, LPTSTR lpcDe
 		if (rv == IFD_SUCCESS && dwGetSize == 1 && ucThread[0] == 1)
 		{
 			(sReadersContexts[dwContextB])->mMutex =
-				(PCSCLITE_MUTEX_T) malloc(sizeof(PCSCLITE_MUTEX));
+				malloc(sizeof(PCSCLITE_MUTEX));
 			SYS_MutexInit((sReadersContexts[dwContextB])->mMutex);
 
-			(sReadersContexts[dwContextB])->pdwMutex = 
-				(DWORD *)malloc(sizeof(DWORD));
+			(sReadersContexts[dwContextB])->pdwMutex = malloc(sizeof(DWORD));
 			*(sReadersContexts[dwContextB])->pdwMutex = 1;
 		}
 		else
@@ -469,7 +466,7 @@ LONG RFAddReader(LPTSTR lpcReader, DWORD dwPort, LPTSTR lpcLibrary, LPTSTR lpcDe
 	return SCARD_S_SUCCESS;
 }
 
-LONG RFRemoveReader(LPTSTR lpcReader, DWORD dwPort)
+LONG RFRemoveReader(LPSTR lpcReader, DWORD dwPort)
 {
 	LONG rv;
 	PREADER_CONTEXT sContext;
@@ -546,8 +543,8 @@ LONG RFRemoveReader(LPTSTR lpcReader, DWORD dwPort)
 	return SCARD_S_SUCCESS;
 }
 
-LONG RFSetReaderName(PREADER_CONTEXT rContext, LPTSTR readerName,
-	LPTSTR libraryName, DWORD dwPort, DWORD dwSlot)
+LONG RFSetReaderName(PREADER_CONTEXT rContext, LPSTR readerName,
+	LPSTR libraryName, DWORD dwPort, DWORD dwSlot)
 {
 	LONG parent = -1;	/* reader number of the parent of the clone */
 	DWORD valueLength;
@@ -655,10 +652,10 @@ LONG RFSetReaderName(PREADER_CONTEXT rContext, LPTSTR readerName,
 }
 
 #if 0
-LONG RFListReaders(LPTSTR lpcReaders, LPDWORD pdwReaderNum)
+LONG RFListReaders(LPSTR lpcReaders, LPDWORD pdwReaderNum)
 {
 	DWORD dwCSize;
-	LPTSTR lpcTReaders;
+	LPSTR lpcTReaders;
 	int i, p;
 
 	if (dwNumReadersContexts == 0)
@@ -732,7 +729,7 @@ LONG RFListReaders(LPTSTR lpcReaders, LPDWORD pdwReaderNum)
 }
 #endif
 
-LONG RFReaderInfo(LPTSTR lpcReader, PREADER_CONTEXT * sReader)
+LONG RFReaderInfo(LPSTR lpcReader, PREADER_CONTEXT * sReader)
 {
 	int i;
 
@@ -754,7 +751,7 @@ LONG RFReaderInfo(LPTSTR lpcReader, PREADER_CONTEXT * sReader)
 	return SCARD_E_UNKNOWN_READER;
 }
 
-LONG RFReaderInfoNamePort(DWORD dwPort, LPTSTR lpcReader,
+LONG RFReaderInfoNamePort(DWORD dwPort, LPSTR lpcReader,
 	PREADER_CONTEXT * sReader)
 {
 	char lpcStripReader[MAX_READERNAME];
@@ -1092,7 +1089,8 @@ LONG RFInitializeReader(PREADER_CONTEXT rContext)
 	/*
 	 * Spawn the event handler thread 
 	 */
-	Log2(PCSC_LOG_INFO, "Attempting startup of %s.", rContext->lpcReader);
+	Log3(PCSC_LOG_INFO, "Attempting startup of %s using %s",
+		rContext->lpcReader, rContext->lpcLibrary);
 
   /******************************************/
 	/*
