@@ -4,7 +4,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: sys_generic.h 1651 2005-09-15 11:35:34Z rousseau $
+ * $Id: sys_generic.h 2076 2006-06-07 12:58:14Z rousseau $
  */
 
 /**
@@ -21,6 +21,7 @@ extern "C"
 #endif
 
 #include <sys/stat.h>
+#include <sys/mman.h>
 
 	int SYS_Initialize(void);
 
@@ -72,6 +73,8 @@ extern "C"
 
 	void *SYS_PublicMemoryMap(int, int, int);
 
+	void SYS_PublicMemoryUnmap(void *, int);
+
 	int SYS_MMapSynchronize(void *, int);
 
 	int SYS_Fork(void);
