@@ -6,7 +6,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: sys_unix.c 1957 2006-03-21 13:59:18Z rousseau $
+ * $Id: sys_unix.c 2076 2006-06-07 12:58:14Z rousseau $
  */
 
 /**
@@ -307,6 +307,7 @@ INTERNAL int SYS_GetPageSize(void)
  * @param[in] iOffset Start point of the file to be mapped in memory.
  *
  * @return Address of the memory map.
+ * @retval MAP_FAILED in case of error
  */
 INTERNAL void *SYS_MemoryMap(int iSize, int iFid, int iOffset)
 {
@@ -343,9 +344,27 @@ INTERNAL void *SYS_PublicMemoryMap(int iSize, int iFid, int iOffset)
 
 	vAddress = 0;
 	vAddress = mmap(0, iSize, PROT_READ, MAP_SHARED, iFid, iOffset);
+	if (vAddress == (void*)-1) // mmap returns -1 on error
+	{
+		Log2(PCSC_LOG_CRITICAL, "SYS_PublicMemoryMap() failed: %s",
+			strerror(errno));
+		vAddress = NULL;
+	}
+
 	return vAddress;
 }
 
+/**
+ * @brief Unmap a memory segment
+ *
+ * @param ptr pointer returned by SYS_PublicMemoryMap()
+ * @param iSize size of the memory segment
+ */
+INTERNAL void SYS_PublicMemoryUnmap(void * ptr, int iSize)
+{
+	munmap(ptr, iSize);
+}
+
 /**
  * @brief Writes the changes made in a memory map to the disk mapped file.
  *
