@@ -5,7 +5,7 @@
  *  David Corcoran <corcoran@linuxnet.com>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard.c 1881 2006-02-24 10:28:06Z rousseau $
+ * $Id: winscard.c 2072 2006-06-06 09:31:07Z rousseau $
  */
 
 /**
@@ -182,7 +182,7 @@ LONG SCardSetTimeout(SCARDCONTEXT hContext, DWORD dwTimeout)
 	return SCARD_E_UNSUPPORTED_FEATURE;
 }
 
-LONG SCardConnect(SCARDCONTEXT hContext, LPCTSTR szReader,
+LONG SCardConnect(SCARDCONTEXT hContext, LPCSTR szReader,
 	DWORD dwShareMode, DWORD dwPreferredProtocols, LPSCARDHANDLE phCard,
 	LPDWORD pdwActiveProtocol)
 {
@@ -212,7 +212,7 @@ LONG SCardConnect(SCARDCONTEXT hContext, LPCTSTR szReader,
 	Log3(PCSC_LOG_DEBUG, "Attempting Connect to %s using protocol: %d",
 		szReader, dwPreferredProtocols);
 
-	rv = RFReaderInfo((LPTSTR) szReader, &rContext);
+	rv = RFReaderInfo((LPSTR) szReader, &rContext);
 
 	if (rv != SCARD_S_SUCCESS)
 	{
@@ -1067,7 +1067,7 @@ LONG SCardCancelTransaction(SCARDHANDLE hCard)
 	return rv;
 }
 
-LONG SCardStatus(SCARDHANDLE hCard, LPTSTR mszReaderNames,
+LONG SCardStatus(SCARDHANDLE hCard, LPSTR mszReaderNames,
 	LPDWORD pcchReaderLen, LPDWORD pdwState,
 	LPDWORD pdwProtocol, LPBYTE pbAtr, LPDWORD pcbAtrLen)
 {
@@ -1420,16 +1420,6 @@ LONG SCardTransmit(SCARDHANDLE hCard, LPCSCARD_IO_REQUEST pioSendPci,
 		}
 	}
 
-	if (cbSendLength > MAX_BUFFER_SIZE)
-	{
-		return SCARD_E_INSUFFICIENT_BUFFER;
-	}
-
-	/*
-	 * Removed - a user may allocate a larger buffer if ( dwRxLength >
-	 * MAX_BUFFER_SIZE ) { return SCARD_E_INSUFFICIENT_BUFFER; }
-	 */
-
 	/*
 	 * Quick fix: PC/SC starts at 1 for bit masking but the IFD_Handler
 	 * just wants 0 or 1
@@ -1501,12 +1491,6 @@ LONG SCardTransmit(SCARDHANDLE hCard, LPCSCARD_IO_REQUEST pioSendPci,
 		return SCARD_E_INSUFFICIENT_BUFFER;
 	}
 
-	if (dwRxLength > MAX_BUFFER_SIZE)
-	{
-		*pcbRecvLength = 0;
-		return SCARD_E_INSUFFICIENT_BUFFER;
-	}
-
 	/*
 	 * Successful return
 	 */
@@ -1514,8 +1498,8 @@ LONG SCardTransmit(SCARDHANDLE hCard, LPCSCARD_IO_REQUEST pioSendPci,
 	return SCARD_S_SUCCESS;
 }
 
-LONG SCardListReaders(SCARDCONTEXT hContext, LPCTSTR mszGroups,
-	LPTSTR mszReaders, LPDWORD pcchReaders)
+LONG SCardListReaders(SCARDCONTEXT hContext, LPCSTR mszGroups,
+	LPSTR mszReaders, LPDWORD pcchReaders)
 {
 	/*
 	 * Client side function
