@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_clnt.c 1958 2006-03-21 14:00:35Z rousseau $
+ * $Id: winscard_clnt.c 2114 2006-07-31 13:28:50Z rousseau $
  */
 
 /**
@@ -129,7 +129,7 @@ static void profile_end(const char *f)
 struct _psChannelMap
 {
 	SCARDHANDLE hCard;
-	LPTSTR readerName;
+	LPSTR readerName;
 };
 
 typedef struct _psChannelMap CHANNEL_MAP, *PCHANNEL_MAP;
@@ -184,7 +184,7 @@ static LONG SCardGetContextIndice(SCARDCONTEXT);
 static LONG SCardGetContextIndiceTH(SCARDCONTEXT);
 static LONG SCardRemoveContext(SCARDCONTEXT);
 
-static LONG SCardAddHandle(SCARDHANDLE, DWORD, LPTSTR);
+static LONG SCardAddHandle(SCARDHANDLE, DWORD, LPSTR);
 static LONG SCardGetIndicesFromHandle(SCARDHANDLE, PDWORD, PDWORD);
 static LONG SCardGetIndicesFromHandleTH(SCARDHANDLE, PDWORD, PDWORD);
 static LONG SCardRemoveHandle(SCARDHANDLE);
@@ -403,14 +403,14 @@ static LONG SCardEstablishContextTH(DWORD dwScope, LPCVOID pvReserved1,
 		veStr->major = PROTOCOL_VERSION_MAJOR;
 		veStr->minor = PROTOCOL_VERSION_MINOR;
 
-		if (-1 == SHMMessageSend(&msgStruct, dwClientID,
+		if (-1 == SHMMessageSend(&msgStruct, sizeof(msgStruct), dwClientID,
 			PCSCLITE_MCLIENT_ATTEMPTS))
 			return SCARD_E_NO_SERVICE;
 
 		/*
 		 * Read a message from the server
 		 */
-		if (-1 == SHMMessageReceive(&msgStruct, dwClientID,
+		if (-1 == SHMMessageReceive(&msgStruct, sizeof(msgStruct), dwClientID,
 			PCSCLITE_CLIENT_ATTEMPTS))
 		{
 			Log1(PCSC_LOG_CRITICAL, "Your pcscd is too old and does not support CMD_VERSION");
@@ -614,7 +614,7 @@ LONG SCardSetTimeout(SCARDCONTEXT hContext, DWORD dwTimeout)
  * rv = SCardConnect(hContext, "Reader X", SCARD_SHARE_SHARED, SCARD_PROTOCOL_T0, &hCard, &dwActiveProtocol);
  * @endcode
  */
-LONG SCardConnect(SCARDCONTEXT hContext, LPCTSTR szReader,
+LONG SCardConnect(SCARDCONTEXT hContext, LPCSTR szReader,
 	DWORD dwShareMode, DWORD dwPreferredProtocols, LPSCARDHANDLE phCard,
 	LPDWORD pdwActiveProtocol)
 {
@@ -701,7 +701,7 @@ LONG SCardConnect(SCARDCONTEXT hContext, LPCTSTR szReader,
 		/*
 		 * Keep track of the handle locally
 		 */
-		rv = SCardAddHandle(*phCard, dwContextIndex, (LPTSTR) szReader);
+		rv = SCardAddHandle(*phCard, dwContextIndex, (LPSTR) szReader);
 		SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
 
 		PROFILE_END
@@ -1374,7 +1374,7 @@ LONG SCardCancelTransaction(SCARDHANDLE hCard)
  * rv=SCardStatus(hCard, NULL, &dwReaderLen, &dwState, &dwProtocol, pbAtr, &dwAtrLen);
  * @endcode
  */
-LONG SCardStatus(SCARDHANDLE hCard, LPTSTR mszReaderNames,
+LONG SCardStatus(SCARDHANDLE hCard, LPSTR mszReaderNames,
 	LPDWORD pcchReaderLen, LPDWORD pdwState,
 	LPDWORD pdwProtocol, LPBYTE pbAtr, LPDWORD pcbAtrLen)
 {
@@ -1531,7 +1531,7 @@ LONG SCardStatus(SCARDHANDLE hCard, LPTSTR mszReaderNames,
  *
  * @code
  * typedef struct {
- *   LPCTSTR szReader;          // Reader name
+ *   LPCSTR szReader;          // Reader name
  *   LPVOID pvUserData;         // User defined data
  *   DWORD dwCurrentState;      // Current state of reader
  *   DWORD dwEventState;        // Reader state after a state change
@@ -1781,7 +1781,7 @@ LONG SCardGetStatusChange(SCARDCONTEXT hContext, DWORD dwTimeout,
 			currReader->dwEventState = SCARD_STATE_IGNORE;
 		} else
 		{
-			LPTSTR lpcReaderName;
+			LPSTR lpcReaderName;
 			int i;
 
 	  /************ Looks for correct readernames *********************/
@@ -2556,8 +2556,6 @@ LONG SCardTransmit(SCARDHANDLE hCard, LPCSCARD_IO_REQUEST pioSendPci,
 	LPDWORD pcbRecvLength)
 {
 	LONG rv;
-	transmit_struct scTransmitStruct;
-	sharedSegmentMsg msgStruct;
 	int i;
 	DWORD dwContextIndex, dwChannelIndex;
 
@@ -2598,76 +2596,168 @@ LONG SCardTransmit(SCARDHANDLE hCard, LPCSCARD_IO_REQUEST pioSendPci,
 		return SCARD_E_READER_UNAVAILABLE;
 	}
 
-	if (cbSendLength > MAX_BUFFER_SIZE)
+	if ((cbSendLength > MAX_BUFFER_SIZE_EXTENDED)
+		|| (*pcbRecvLength > MAX_BUFFER_SIZE_EXTENDED))
 	{
 		SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
 		return SCARD_E_INSUFFICIENT_BUFFER;
 	}
 
-	scTransmitStruct.hCard = hCard;
-	scTransmitStruct.cbSendLength = cbSendLength;
-	scTransmitStruct.pcbRecvLength = *pcbRecvLength;
-	memcpy(&scTransmitStruct.pioSendPci, pioSendPci,
-		sizeof(SCARD_IO_REQUEST));
-	memcpy(scTransmitStruct.pbSendBuffer, pbSendBuffer, cbSendLength);
-
-	if (pioRecvPci)
+	if ((cbSendLength > MAX_BUFFER_SIZE) || (*pcbRecvLength > MAX_BUFFER_SIZE))
 	{
-		memcpy(&scTransmitStruct.pioRecvPci, pioRecvPci,
+		/* extended APDU */
+		unsigned char buffer[sizeof(sharedSegmentMsg) + MAX_BUFFER_SIZE_EXTENDED];
+		transmit_struct_extended *scTransmitStructExtended = (transmit_struct_extended *)buffer;
+		sharedSegmentMsg *pmsgStruct = (psharedSegmentMsg)buffer;
+
+		scTransmitStructExtended->hCard = hCard;
+		scTransmitStructExtended->cbSendLength = cbSendLength;
+		scTransmitStructExtended->pcbRecvLength = *pcbRecvLength;
+		scTransmitStructExtended->size = sizeof(*scTransmitStructExtended) + cbSendLength;
+		memcpy(&scTransmitStructExtended->pioSendPci, pioSendPci,
 			sizeof(SCARD_IO_REQUEST));
-	}
-	else
-		scTransmitStruct.pioRecvPci.dwProtocol = SCARD_PROTOCOL_ANY;
-
-	rv = WrapSHMWrite(SCARD_TRANSMIT, psContextMap[dwContextIndex].dwClientID,
-		sizeof(scTransmitStruct),
-		PCSCLITE_CLIENT_ATTEMPTS, (void *) &scTransmitStruct);
-
-	if (rv == -1)
-	{
-		SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
-		return SCARD_E_NO_SERVICE;
-	}
-
-	/*
-	 * Read a message from the server
-	 */
-	rv = SHMClientRead(&msgStruct, psContextMap[dwContextIndex].dwClientID, PCSCLITE_CLIENT_ATTEMPTS);
-
-	memcpy(&scTransmitStruct, &msgStruct.data, sizeof(scTransmitStruct));
-
-	if (rv == -1)
-	{
-		SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
-		return SCARD_F_COMM_ERROR;
-	}
-
-	/*
-	 * Zero it and free it so any secret information cannot be leaked
-	 */
-	memset(scTransmitStruct.pbSendBuffer, 0x00, cbSendLength);
-
-	if (scTransmitStruct.rv == SCARD_S_SUCCESS)
-	{
-		/*
-		 * Copy and zero it so any secret information is not leaked
-		 */
-		memcpy(pbRecvBuffer, scTransmitStruct.pbRecvBuffer,
-			scTransmitStruct.pcbRecvLength);
-		memset(scTransmitStruct.pbRecvBuffer, 0x00,
-			scTransmitStruct.pcbRecvLength);
+		memcpy(scTransmitStructExtended->data, pbSendBuffer, cbSendLength);
 
 		if (pioRecvPci)
-			memcpy(pioRecvPci, &scTransmitStruct.pioRecvPci,
+		{
+			memcpy(&scTransmitStructExtended->pioRecvPci, pioRecvPci,
 				sizeof(SCARD_IO_REQUEST));
-	}
+		}
+		else
+			scTransmitStructExtended->pioRecvPci.dwProtocol = SCARD_PROTOCOL_ANY;
 
-	*pcbRecvLength = scTransmitStruct.pcbRecvLength;
-	SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
+		rv = WrapSHMWrite(SCARD_TRANSMIT_EXTENDED,
+			psContextMap[dwContextIndex].dwClientID,
+			scTransmitStructExtended->size,
+			PCSCLITE_CLIENT_ATTEMPTS, buffer);
+
+		if (rv == -1)
+		{
+			SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
+			return SCARD_E_NO_SERVICE;
+		}
+
+		/*
+		 * Read a message from the server
+		 */
+		/* read the first block */
+		rv = SHMMessageReceive(buffer, sizeof(sharedSegmentMsg), psContextMap[dwContextIndex].dwClientID, PCSCLITE_CLIENT_ATTEMPTS);
+		if (rv == -1)
+		{
+			SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
+			return SCARD_F_COMM_ERROR;
+		}
+
+		/* we receive a sharedSegmentMsg and not a transmit_struct_extended */
+		scTransmitStructExtended = (transmit_struct_extended *)&(pmsgStruct -> data);
+
+		/* a second block is present */
+		if (scTransmitStructExtended->size > PCSCLITE_MAX_MESSAGE_SIZE)
+		{
+			rv = SHMMessageReceive(buffer + sizeof(sharedSegmentMsg),
+				scTransmitStructExtended->size-PCSCLITE_MAX_MESSAGE_SIZE,
+				psContextMap[dwContextIndex].dwClientID,
+				PCSCLITE_CLIENT_ATTEMPTS);
+			if (rv == -1)
+			{
+				SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
+				return SCARD_F_COMM_ERROR;
+			}
+		}
+
+		if (scTransmitStructExtended -> rv == SCARD_S_SUCCESS)
+		{
+			/*
+			 * Copy and zero it so any secret information is not leaked
+			 */
+			memcpy(pbRecvBuffer, scTransmitStructExtended -> data,
+				scTransmitStructExtended -> pcbRecvLength);
+			memset(scTransmitStructExtended -> data, 0x00,
+				scTransmitStructExtended -> pcbRecvLength);
+
+			if (pioRecvPci)
+				memcpy(pioRecvPci, &scTransmitStructExtended -> pioRecvPci,
+					sizeof(SCARD_IO_REQUEST));
+		}
+
+		*pcbRecvLength = scTransmitStructExtended -> pcbRecvLength;
+		SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
+
+		rv = scTransmitStructExtended -> rv;
+	}
+	else
+	{
+		/* short APDU */
+		transmit_struct scTransmitStruct;
+		sharedSegmentMsg msgStruct;
+
+		scTransmitStruct.hCard = hCard;
+		scTransmitStruct.cbSendLength = cbSendLength;
+		scTransmitStruct.pcbRecvLength = *pcbRecvLength;
+		memcpy(&scTransmitStruct.pioSendPci, pioSendPci,
+			sizeof(SCARD_IO_REQUEST));
+		memcpy(scTransmitStruct.pbSendBuffer, pbSendBuffer, cbSendLength);
+
+		if (pioRecvPci)
+		{
+			memcpy(&scTransmitStruct.pioRecvPci, pioRecvPci,
+				sizeof(SCARD_IO_REQUEST));
+		}
+		else
+			scTransmitStruct.pioRecvPci.dwProtocol = SCARD_PROTOCOL_ANY;
+
+		rv = WrapSHMWrite(SCARD_TRANSMIT,
+			psContextMap[dwContextIndex].dwClientID, sizeof(scTransmitStruct),
+			PCSCLITE_CLIENT_ATTEMPTS, (void *) &scTransmitStruct);
+
+		if (rv == -1)
+		{
+			SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
+			return SCARD_E_NO_SERVICE;
+		}
+
+		/*
+		 * Read a message from the server
+		 */
+		rv = SHMClientRead(&msgStruct, psContextMap[dwContextIndex].dwClientID, PCSCLITE_CLIENT_ATTEMPTS);
+
+		memcpy(&scTransmitStruct, &msgStruct.data, sizeof(scTransmitStruct));
+
+		if (rv == -1)
+		{
+			SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
+			return SCARD_F_COMM_ERROR;
+		}
+
+		/*
+		 * Zero it and free it so any secret information cannot be leaked
+		 */
+		memset(scTransmitStruct.pbSendBuffer, 0x00, cbSendLength);
+
+		if (scTransmitStruct.rv == SCARD_S_SUCCESS)
+		{
+			/*
+			 * Copy and zero it so any secret information is not leaked
+			 */
+			memcpy(pbRecvBuffer, scTransmitStruct.pbRecvBuffer,
+				scTransmitStruct.pcbRecvLength);
+			memset(scTransmitStruct.pbRecvBuffer, 0x00,
+				scTransmitStruct.pcbRecvLength);
+
+			if (pioRecvPci)
+				memcpy(pioRecvPci, &scTransmitStruct.pioRecvPci,
+					sizeof(SCARD_IO_REQUEST));
+		}
+
+		*pcbRecvLength = scTransmitStruct.pcbRecvLength;
+		SYS_MutexUnLock(psContextMap[dwContextIndex].mMutex);	
+
+		rv = scTransmitStruct.rv;
+	}
 
 	PROFILE_END
 
-	return scTransmitStruct.rv;
+	return rv;
 }
 
 /**
@@ -2689,18 +2779,18 @@ LONG SCardTransmit(SCARDHANDLE hCard, LPCSCARD_IO_REQUEST pioSendPci,
  * @test
  * @code
  * SCARDCONTEXT hContext;
- * LPTSTR mszReaders;
+ * LPSTR mszReaders;
  * DWORD dwReaders;
  * LONG rv;
  * ...
  * rv = SCardEstablishContext(SCARD_SCOPE_SYSTEM, NULL, NULL, &hContext);
  * rv = SCardListReaders(hContext, NULL, NULL, &dwReaders);
- * mszReaders = (LPTSTR)malloc(sizeof(char)*dwReaders);
+ * mszReaders = malloc(sizeof(char)*dwReaders);
  * rv = SCardListReaders(hContext, NULL, mszReaders, &dwReaders); 
  * @endcode
  */
-LONG SCardListReaders(SCARDCONTEXT hContext, LPCTSTR mszGroups,
-	LPTSTR mszReaders, LPDWORD pcchReaders)
+LONG SCardListReaders(SCARDCONTEXT hContext, LPCSTR mszGroups,
+	LPSTR mszReaders, LPDWORD pcchReaders)
 {
 	DWORD dwReadersLen;
 	int i, lastChrPtr;
@@ -2793,17 +2883,17 @@ LONG SCardListReaders(SCARDCONTEXT hContext, LPCTSTR mszGroups,
  * @test
  * @code
  * SCARDCONTEXT hContext;
- * LPTSTR mszGroups;
+ * LPSTR mszGroups;
  * DWORD dwGroups;
  * LONG rv;
  * ...
  * rv = SCardEstablishContext(SCARD_SCOPE_SYSTEM, NULL, NULL, &hContext);
  * rv = SCardListReaderGroups(hContext, NULL, &dwGroups);
- * mszGroups = (LPTSTR)malloc(sizeof(char)*dwGroups);
+ * mszGroups = malloc(sizeof(char)*dwGroups);
  * rv = SCardListReaderGroups(hContext, mszGroups, &dwGroups);
  * @endcode
  */
-LONG SCardListReaderGroups(SCARDCONTEXT hContext, LPTSTR mszGroups,
+LONG SCardListReaderGroups(SCARDCONTEXT hContext, LPSTR mszGroups,
 	LPDWORD pcchGroups)
 {
 	LONG rv = SCARD_S_SUCCESS;
@@ -2923,7 +3013,7 @@ static LONG SCardAddContext(SCARDCONTEXT hContext, DWORD dwClientID)
 			psContextMap[i].hContext = hContext;
 			psContextMap[i].dwClientID = dwClientID;
 			psContextMap[i].contextBlockStatus = BLOCK_STATUS_RESUME;
-			psContextMap[i].mMutex = (PCSCLITE_MUTEX_T) malloc(sizeof(PCSCLITE_MUTEX));
+			psContextMap[i].mMutex = malloc(sizeof(PCSCLITE_MUTEX));
 			SYS_MutexInit(psContextMap[i].mMutex);
 			return SCARD_S_SUCCESS;
 		}
@@ -3030,7 +3120,7 @@ static LONG SCardRemoveContext(SCARDCONTEXT hContext)
  */
 
 static LONG SCardAddHandle(SCARDHANDLE hCard, DWORD dwContextIndex,
-	LPTSTR readerName)
+	LPSTR readerName)
 {
 	int i;
 
@@ -3135,7 +3225,7 @@ static LONG SCardCheckDaemonAvailability(void)
 	LONG rv;
 	struct stat statBuffer;
 
-	rv = SYS_Stat(PCSCLITE_IPC_DIR, &statBuffer);
+	rv = SYS_Stat(PCSCLITE_PUBSHM_FILE, &statBuffer);
 
 	if (rv != 0)
 	{
@@ -3157,9 +3247,21 @@ static LONG SCardCheckDaemonAvailability(void)
 
 void DESTRUCTOR SCardUnload(void)
 {
+	int i;
+
 	if (!isExecuted)
 		return;
 
+	// unmap public shared file from memory
+	for (i = 0; i < PCSCLITE_MAX_APPLICATION_CONTEXT_CHANNELS; i++)
+	{
+		if (readerStates[i] != NULL)
+		{
+			SYS_PublicMemoryUnmap(readerStates[i], sizeof(READER_STATE));
+			readerStates[i] = NULL;
+		}
+	}
+
 	SYS_CloseFile(mapAddr);
 	isExecuted = 0;
 }
