@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludoic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_msg.c 1957 2006-03-21 13:59:18Z rousseau $
+ * $Id: winscard_msg.c 2074 2006-06-06 09:42:01Z rousseau $
  */
 
 /**
@@ -55,7 +55,7 @@
  */
 INTERNAL int SHMClientRead(psharedSegmentMsg msgStruct, DWORD dwClientID, int blockamount)
 {
-	return SHMMessageReceive(msgStruct, dwClientID, blockamount);
+	return SHMMessageReceive(msgStruct, sizeof(*msgStruct), dwClientID, blockamount);
 }
 
 /**
@@ -126,7 +126,8 @@ INTERNAL int SHMClientCloseSession(DWORD dwClientID)
  *
  * Writes the message in the shared file \c filedes.
  *
- * @param[in] msgStruct Message to be sent.
+ * @param[in] buffer Message to be sent.
+ * @param[in] buffer_size Size of the message to send
  * @param[in] filedes Socket handle.
  * @param[in] blockAmount Timeout in milliseconds.
  *
@@ -135,8 +136,8 @@ INTERNAL int SHMClientCloseSession(DWORD dwClientID)
  * @retval -1 Socket is closed.
  * @retval -1 A signal was received.
  */
-INTERNAL int SHMMessageSend(psharedSegmentMsg msgStruct, int filedes,
-	int blockAmount)
+INTERNAL int SHMMessageSend(void *buffer, size_t buffer_size,
+	int filedes, int blockAmount)
 {
 	/*
 	 * default is success 
@@ -146,14 +147,10 @@ INTERNAL int SHMMessageSend(psharedSegmentMsg msgStruct, int filedes,
 	 * record the time when we started 
 	 */
 	time_t start = time(0);
-	/*
-	 * data to be written 
-	 */
-	unsigned char *buffer = (unsigned char *) msgStruct;
 	/*
 	 * how many bytes remains to be written 
 	 */
-	size_t remaining = sizeof(sharedSegmentMsg);
+	size_t remaining = buffer_size;
 
 	/*
 	 * repeat until all data is written 
@@ -252,7 +249,8 @@ INTERNAL int SHMMessageSend(psharedSegmentMsg msgStruct, int filedes,
  *
  * Reads the message from the file \c filedes.
  *
- * @param[out] msgStruct Message read.
+ * @param[out] buffer Message read.
+ * @param[in] buffer_size Size to read
  * @param[in] filedes Socket handle.
  * @param[in] blockAmount Timeout in milliseconds.
  *
@@ -261,8 +259,8 @@ INTERNAL int SHMMessageSend(psharedSegmentMsg msgStruct, int filedes,
  * @retval -1 Socket is closed.
  * @retval -1 A signal was received.
  */
-INTERNAL int SHMMessageReceive(psharedSegmentMsg msgStruct, int filedes,
-	int blockAmount)
+INTERNAL int SHMMessageReceive(void *buffer, size_t buffer_size,
+	int filedes, int blockAmount)
 {
 	/*
 	 * default is success 
@@ -272,14 +270,10 @@ INTERNAL int SHMMessageReceive(psharedSegmentMsg msgStruct, int filedes,
 	 * record the time when we started 
 	 */
 	time_t start = time(0);
-	/*
-	 * buffer where we place the readed bytes 
-	 */
-	unsigned char *buffer = (unsigned char *) msgStruct;
 	/*
 	 * how many bytes we must read 
 	 */
-	size_t remaining = sizeof(sharedSegmentMsg);
+	size_t remaining = buffer_size;
 
 	/*
 	 * repeate until we get the whole message 
@@ -392,6 +386,7 @@ INTERNAL int WrapSHMWrite(unsigned int command, DWORD dwClientID,
 	unsigned int size, unsigned int blockAmount, void *data)
 {
 	sharedSegmentMsg msgStruct;
+	int ret;
 
 	/*
 	 * Set the appropriate packet parameters 
@@ -403,9 +398,33 @@ INTERNAL int WrapSHMWrite(unsigned int command, DWORD dwClientID,
 	msgStruct.group_id = SYS_GetGID();
 	msgStruct.command = command;
 	msgStruct.date = time(NULL);
-	memcpy(msgStruct.data, data, size);
+	if (SCARD_TRANSMIT_EXTENDED == command)
+	{
+		/* first block */
+		memcpy(msgStruct.data, data, PCSCLITE_MAX_MESSAGE_SIZE);
+		ret = SHMMessageSend(&msgStruct, sizeof(msgStruct), dwClientID,
+			blockAmount);
+		if (ret)
+			return ret;
 
-	return SHMMessageSend(&msgStruct, dwClientID, blockAmount);
+		/* do not send an empty second block */
+		if (size > PCSCLITE_MAX_MESSAGE_SIZE)
+		{
+			/* second block */
+			ret = SHMMessageSend(data+PCSCLITE_MAX_MESSAGE_SIZE,
+				size-PCSCLITE_MAX_MESSAGE_SIZE, dwClientID, blockAmount);
+			if (ret)
+				return ret;
+		}
+	}
+	else
+	{
+		memcpy(msgStruct.data, data, size);
+
+		ret = SHMMessageSend(&msgStruct, sizeof(msgStruct), dwClientID,
+			blockAmount);
+	}
+	return ret;
 }
 
 /**
