@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_msg.h 1695 2005-10-29 16:27:33Z rousseau $
+ * $Id: winscard_msg.h 2060 2006-05-25 21:35:58Z rousseau $
  */
 
 /**
@@ -21,7 +21,7 @@
 /** Major version of the current message protocol */
 #define PROTOCOL_VERSION_MAJOR 2
 /** Minor version of the current message protocol */
-#define PROTOCOL_VERSION_MINOR 0
+#define PROTOCOL_VERSION_MINOR 1
 
 #ifdef __cplusplus
 extern "C"
@@ -87,7 +87,8 @@ extern "C"
 		SCARD_CANCEL = 0x0D,
 		SCARD_CANCEL_TRANSACTION = 0x0E,
 		SCARD_GET_ATTRIB = 0x0F,
-		SCARD_SET_ATTRIB = 0x10
+		SCARD_SET_ATTRIB = 0x10,
+		SCARD_TRANSMIT_EXTENDED = 0x11
 	};
 
 	/**
@@ -251,6 +252,24 @@ extern "C"
 	};
 	typedef struct transmit_struct transmit_struct;
 
+	/**
+	 * @brief contained in \c SCARD_TRANSMIT_EXTENDED Messages.
+	 *
+	 * These data are passed throw the field \c sharedSegmentMsg.data.
+	 */
+	struct transmit_struct_extended
+	{
+		SCARDHANDLE hCard;
+		SCARD_IO_REQUEST pioSendPci;
+		DWORD cbSendLength;
+		SCARD_IO_REQUEST pioRecvPci;
+		DWORD pcbRecvLength;
+		LONG rv;
+		size_t size;
+		BYTE data[0];
+	};
+	typedef struct transmit_struct_extended transmit_struct_extended;
+
 	/**
 	 * @brief contained in \c SCARD_CONTROL Messages.
 	 *
@@ -294,10 +313,12 @@ extern "C"
 	int SHMInitializeCommonSegment(void);
 	int SHMProcessEventsContext(PDWORD, psharedSegmentMsg, int);
 	int SHMProcessEventsServer(PDWORD, int);
-	int SHMMessageSend(psharedSegmentMsg, int, int);
-	int SHMMessageReceive(psharedSegmentMsg, int, int);
-	int WrapSHMWrite(unsigned int, DWORD, unsigned int,
-		unsigned int, void *);
+	int SHMMessageSend(void *buffer, size_t buffer_size, int filedes,
+		int blockAmount);
+	int SHMMessageReceive(void *buffer, size_t buffer_size,
+		int filedes, int blockAmount);
+	int WrapSHMWrite(unsigned int command, DWORD dwClientID, unsigned int size,
+		unsigned int blockAmount, void *data);
 	void SHMCleanupSharedSegment(int, char *);
 
 #ifdef __cplusplus
