@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_svc.c 1998 2006-04-11 09:06:50Z rousseau $
+ * $Id: winscard_svc.c 2128 2006-08-08 15:05:57Z rousseau $
  */
 
 /**
@@ -91,6 +91,8 @@ LONG CreateContextThread(PDWORD pdwClientID)
 	{
 		SYS_CloseFile(psContext[i].dwClientID);
 		psContext[i].dwClientID = 0; 
+		Log2(PCSC_LOG_CRITICAL, "No more context available (max: %d)",
+			PCSCLITE_MAX_APPLICATIONS_CONTEXTS);
 		return SCARD_F_INTERNAL_ERROR;
 	}
 	
@@ -100,6 +102,7 @@ LONG CreateContextThread(PDWORD pdwClientID)
 	{
 		SYS_CloseFile(psContext[i].dwClientID);
 		psContext[i].dwClientID = 0; 
+		Log1(PCSC_LOG_CRITICAL, "SYS_ThreadCreate failed");
 		return SCARD_E_NO_MEMORY;
 	}
 
@@ -152,8 +155,13 @@ static void ContextThread(LPVOID dwIndex)
 				 * Command must be found
 				 */
 				MSGFunctionDemarshall(&msgStruct, dwContextIndex);
-				rv = SHMMessageSend(&msgStruct, psContext[dwContextIndex].dwClientID,
-						    PCSCLITE_SERVER_ATTEMPTS);
+
+				/* the SCARD_TRANSMIT_EXTENDED anwser is already sent by
+				 * MSGFunctionDemarshall */
+				if (msgStruct.command != SCARD_TRANSMIT_EXTENDED)
+					rv = SHMMessageSend(&msgStruct, sizeof(msgStruct),
+						psContext[dwContextIndex].dwClientID,
+						PCSCLITE_SERVER_ATTEMPTS);
 			}
 			else
 				/* pcsc-lite client/server protocol version */
@@ -176,7 +184,7 @@ static void ContextThread(LPVOID dwIndex)
 					veStr->rv = SCARD_S_SUCCESS;
 
 					/* send back the response */
-					rv = SHMMessageSend(&msgStruct,
+					rv = SHMMessageSend(&msgStruct, sizeof(msgStruct),
 						psContext[dwContextIndex].dwClientID,
 					    PCSCLITE_SERVER_ATTEMPTS);
 				}
@@ -363,7 +371,77 @@ LONG MSGFunctionDemarshall(psharedSegmentMsg msgStruct, DWORD dwContextIndex)
 			gsStr->pbAttr, gsStr->cbAttrLen);
 		break;
 
+	case SCARD_TRANSMIT_EXTENDED:
+		{
+			transmit_struct_extended *treStr;
+			unsigned char pbSendBuffer[MAX_BUFFER_SIZE_EXTENDED];
+			unsigned char pbRecvBuffer[MAX_BUFFER_SIZE_EXTENDED];
+
+			treStr = ((transmit_struct_extended *) msgStruct->data);
+			rv = MSGCheckHandleAssociation(treStr->hCard, dwContextIndex);
+			if (rv != 0) return rv;
+
+			/* on more block to read? */
+			if (treStr->size > PCSCLITE_MAX_MESSAGE_SIZE)
+			{
+				/* copy the first APDU part */
+				memcpy(pbSendBuffer, treStr->data,
+					PCSCLITE_MAX_MESSAGE_SIZE-sizeof(*treStr));
+
+				/* receive the second block */
+				rv = SHMMessageReceive(
+					pbSendBuffer+PCSCLITE_MAX_MESSAGE_SIZE-sizeof(*treStr),
+					treStr->size - PCSCLITE_MAX_MESSAGE_SIZE,
+					psContext[dwContextIndex].dwClientID,
+					PCSCLITE_SERVER_ATTEMPTS);
+				if (rv)
+					Log1(PCSC_LOG_CRITICAL, "reception failed");
+			}
+			else
+				memcpy(pbSendBuffer, treStr->data, treStr->cbSendLength);
+
+			treStr->rv = SCardTransmit(treStr->hCard, &treStr->pioSendPci,
+				pbSendBuffer, treStr->cbSendLength,
+				&treStr->pioRecvPci, pbRecvBuffer,
+				&treStr->pcbRecvLength);
+
+			treStr->size = sizeof(*treStr) + treStr->pcbRecvLength;
+			if (treStr->size > PCSCLITE_MAX_MESSAGE_SIZE)
+			{
+				/* two blocks */
+				memcpy(treStr->data, pbRecvBuffer, PCSCLITE_MAX_MESSAGE_SIZE
+					- sizeof(*treStr));
+
+				rv = SHMMessageSend(msgStruct, sizeof(*msgStruct),
+					psContext[dwContextIndex].dwClientID,
+					PCSCLITE_SERVER_ATTEMPTS);
+				if (rv)
+					Log1(PCSC_LOG_CRITICAL, "transmission failed");
+
+				rv = SHMMessageSend(pbRecvBuffer + PCSCLITE_MAX_MESSAGE_SIZE
+					- sizeof(*treStr),
+					treStr->size - PCSCLITE_MAX_MESSAGE_SIZE, 
+					psContext[dwContextIndex].dwClientID,
+					PCSCLITE_SERVER_ATTEMPTS);
+				if (rv)
+					Log1(PCSC_LOG_CRITICAL, "transmission failed");
+			}
+			else
+			{
+				/* one block only */
+				memcpy(treStr->data, pbRecvBuffer, treStr->pcbRecvLength);
+
+				rv = SHMMessageSend(msgStruct, sizeof(*msgStruct),
+					psContext[dwContextIndex].dwClientID,
+					PCSCLITE_SERVER_ATTEMPTS);
+				if (rv)
+					Log1(PCSC_LOG_CRITICAL, "transmission failed");
+			}
+		}
+		break;
+
 	default:
+		Log2(PCSC_LOG_CRITICAL, "Unknown command: %d", msgStruct->command);
 		return -1;
 	}
 
